BoardListCallbacks class

Container for board list callbacks

Constructors

BoardListCallbacks({BoardListScrollCallback? onScroll, BoardListScrollStateCallback? onScrollStateChanged, BoardItemVisibilityCallback? onItemVisibilityChanged, BoardErrorCallback? onError})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
onError → BoardErrorCallback?
final
onItemVisibilityChanged → BoardItemVisibilityCallback?
final
onScroll → BoardListScrollCallback?
final
onScrollStateChanged → BoardListVisibilityCallback?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({BoardListScrollCallback? onScroll, BoardListScrollStateCallback? onScrollStateChanged, BoardItemVisibilityCallback? onItemVisibilityChanged, BoardErrorCallback? onError}) → BoardListCallbacks
Creates a copy of this callbacks object with some values replaced
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited