BoardListController class

A specialized controller for individual board lists

Inheritance

Constructors

BoardListController()

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
isAttached → bool
Whether the controller is attached to a scrollable widget
no setter
isScrolling → bool
Whether this list is currently scrolling
no setter
listIndex → int
The index of this list in the board
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollPosition → double
The current scroll position
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
animateToItem(int itemIndex, {Duration duration = const Duration(milliseconds: 300), Curve curve = Curves.ease}) → Future<void>
Animates to a specific item index within the list
attachScrollController(ScrollController controller) → void
Attaches the scroll controller
dispose() → void
Discards any resources used by the object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyItemVisibilityChanged(int itemIndex, bool isVisible) → void
Notifies about item visibility change
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
scrollToBottom({Duration duration = const Duration(milliseconds: 300), Curve curve = Curves.ease}) → Future<void>
Scrolls to the bottom of the list
scrollToTop({Duration duration = const Duration(milliseconds: 300), Curve curve = Curves.ease}) → Future<void>
Scrolls to the top of the list
setCallbacks(BoardListCallbacks? callbacks) → void
Sets the callbacks for state changes
setListIndex(int index) → void
Sets the list index
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited