BoardDataState class

Manages the overall state of the board

Inheritance

Constructors

BoardDataState()

Properties

dragState → BoardDragState
The drag state manager
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
lists → List<List<Widget>>
The current lists in the board
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addItem(int listIndex, Widget item) → void
Adds an item to a specific list
addList(List<Widget> list) → void
Adds a new list to the board
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
override
moveItem({required int fromListIndex, required int fromItemIndex, required int toListIndex, required int toItemIndex}) → void
Moves an item from one position to another
moveList({required int fromIndex, required int toIndex}) → void
Reorders a list
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeItem(int listIndex, int itemIndex) → void
Removes an item from a specific list
removeList(int index) → void
Removes a list from the board
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setCallbacks(BoardCallbacks? callbacks) → void
Sets the callbacks for state changes
toString() → String
A string representation of this object.
inherited
updateLists(List<List<Widget>> newLists) → void
Updates the board lists

Operators

operator ==(Object other) → bool
The equality operator.
inherited