BoardItemState class

Represents the state of a board item during drag operations

Constructors

BoardItemState({required int listIndex, required int itemIndex, required Widget widget, required Offset position, required Size size})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
itemIndex → int
final
listIndex → int
final
position → Offset
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → Size
final
widget → Widget
final

Methods

copyWith({int? listIndex, int? itemIndex, Widget? widget, Offset? position, Size? size}) → BoardItemState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited