BoardViewController class

Legacy BoardViewController for backward compatibility Consider using the new BoardController instead

Annotations

Constructors

BoardViewController()

Properties

controller → BoardController
Gets the underlying modern controller
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

animateTo(int index, {Duration? duration, Curve? curve}) → Future<void>
Animates to a specific list index
dispose() → void
Disposes the controller
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited